==> qt4-debuginfo-4.8.7-3.tar.xz: usr/src/debug/qt4-4.8.7-3/tools/designer/src/components/lib/.rcc/release-shared/qrc_propertyeditor.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt4/qt4-4.8.7-3.x86_64/src/qt-everywhere-opensource-src-4.8.7/tools/designer/src/components/propertyeditor/fontmapping.xml
  0x0,0x0,0x3,0x8d,
  0x0,
  0x0,0x10,0x80,0x78,0x9c,0xed,0x56,0x61,0x6f,0xdb,0x36,0x10,0xfd,0x9e,0x5f,0x71,
  0x33,0x82,0x61,0x1b,0x22,0x29,0xee,0x50,0xa0,0xc8,0xdc,0x14,0xad,0xa3,0x4,0x1,
  0x3c,0xd7,0x45,0x94,0x6e,0x45,0x51,0x4,0xb4,0x74,0x96,0xb9,0x52,0xa4,0x42,0x52,
  0x56,0xfc,0xef,0x77,0xa4,0xa4,0xd8,0x71,0xec,0x21,0x3,0xd2,0xa2,0x1f,0x6c,0x18,
  0xb0,0xcd,0x3b,0xbe,0x77,0x7c,0xf7,0x8e,0xf2,0xe0,0xcd,0x5d,0x21,0x60,0x81,0xda,
  0x70,0x25,0x5f,0xf7,0xfa,0xe1,0x71,0xf,0x50,0xa6,0x2a,0xe3,0x32,0x7f,0xdd,0xbb,
  0x4e,0xce,0x83,0x57,0xbd,0x37,0xa7,0x7,0x7,0x83,0x9f,0x82,0xe0,0xb7,0x67,0x7a,
  0x1d,0xf8,0x37,0xc,0x55,0xb9,0xd4,0x3c,0x9f,0x5b,0xf8,0x65,0xf8,0x2b,0xbc,0x38,
  0xee,0xbf,0x84,0x64,0x8e,0xf0,0xc1,0x52,0xa4,0x28,0x99,0x5c,0xc2,0xc8,0x66,0x61,
  0x93,0x29,0x2d,0x4b,0xed,0x9,0xcc,0xad,0x2d,0x4f,0xa2,0xa8,0xae,0xeb,0xf0,0xd6,
  0x86,0x5c,0x45,0x82,0xa7,0x28,0xd,0xd5,0x1a,0xb5,0xa0,0xc9,0x9c,0x1b,0x98,0x71,
  0x81,0x40,0x9f,0x25,0xd3,0x16,0xd4,0xc,0x6c,0x3,0x7b,0x86,0x86,0xe7,0x12,0xf5,
  0xda,0x52,0xa2,0x94,0xf8,0xca,0x6d,0xd8,0xee,0x3e,0xfc,0x90,0xdc,0xbc,0x8b,0x2f,
  0x2e,0xc7,0x37,0xa3,0xcb,0x61,0x3c,0xbe,0x8a,0x4f,0x46,0x17,0x93,0xd1,0x61,0x53,
  0x43,0x51,0xa0,0x4e,0x39,0x13,0x30,0xf2,0xa4,0x8,0xd7,0x86,0xe5,0xe8,0x62,0xed,
  0x2,0x1a,0x98,0x2b,0xe1,0x94,0x83,0x5,0x13,0x3c,0x83,0x74,0xb5,0x87,0xb8,0x9a,
  0x5a,0x29,0xa9,0x60,0x4b,0xa8,0x68,0xbf,0x5d,0xd5,0x2a,0x1d,0xc,0x4b,0x53,0xa5,
  0x33,0x26,0x53,0x84,0x9a,0xdb,0xb9,0xaf,0x71,0xd,0xa2,0xdd,0xf,0x2c,0xd7,0x88,
  0x5,0x4a,0xb,0xa5,0x56,0xb,0x9e,0x61,0x76,0x9f,0xee,0x50,0xae,0xd4,0xcc,0xd6,
  0x4c,0x23,0x28,0x7d,0x4,0x4c,0x58,0xd4,0x92,0x59,0xbe,0x40,0xb1,0x3c,0x22,0x9e,
  0xad,0x24,0x94,0x53,0x18,0xa2,0x22,0x95,0xb9,0x24,0xb8,0xb6,0x1c,0xa8,0x35,0xb7,
  0x16,0xe5,0x1a,0xe3,0x14,0x6d,0x8d,0xb4,0xb2,0x54,0x15,0x30,0x99,0x6d,0x34,0x2c,
  0x84,0x73,0xa5,0xe1,0xbe,0x27,0xd,0xae,0x87,0x92,0x4e,0xc,0x99,0x71,0x4b,0x2e,
  0x33,0x40,0x52,0x3d,0x6e,0xa5,0x4f,0xe,0x56,0x59,0xd,0xd8,0xac,0xd2,0x54,0xa1,
  0x76,0x20,0x5c,0xce,0x94,0x2e,0x98,0xb,0xb6,0xf2,0x61,0x53,0x73,0x6a,0xc1,0x45,
  0x80,0xd9,0xc7,0xa8,0x6d,0x42,0x50,0x99,0xae,0xc7,0x17,0xe3,0x6b,0x18,0xa1,0x31,
  0xe4,0x83,0xb,0x24,0x37,0x90,0xb2,0x93,0x6a,0x4a,0x45,0x3f,0xee,0xeb,0xdb,0x87,
  0xea,0xad,0xfa,0xe5,0x3a,0x38,0x45,0x57,0x45,0x6,0x95,0xcc,0x8,0x6a,0x25,0x63,
  0x6b,0xae,0x15,0x8d,0x27,0xdd,0xce,0xd4,0xce,0x1d,0xbc,0x8,0xfb,0xc0,0xc8,0xaf,
  0x2e,0x6a,0xe6,0x4,0x3a,0x5d,0x7a,0x90,0x73,0xd2,0xfd,0xbe,0xa1,0xe,0xe7,0x5c,
  0x11,0x5d,0x23,0x81,0xd3,0x94,0x95,0x25,0x32,0xed,0xa4,0xa6,0xce,0xba,0xd,0xbe,
  0xba,0xd6,0xbb,0xa1,0xf3,0x2e,0x5,0x52,0x51,0x65,0xbe,0xa9,0x9d,0x43,0x4a,0x96,
  0x7e,0x65,0xb9,0xdb,0xe5,0x6b,0x6d,0xf,0x15,0x2,0x4c,0x4,0x32,0xaa,0x4a,0xe3,
  0x82,0x63,0xdd,0xe0,0x29,0x21,0x54,0xdd,0x10,0xac,0xd4,0xb7,0xca,0xc1,0xd0,0x9,
  0x2a,0x8d,0x1b,0x87,0x7d,0xca,0x49,0x35,0xde,0x56,0x5c,0x7b,0x43,0x79,0x77,0xd4,
  0x5c,0x8,0x27,0x67,0x81,0xf,0x47,0x3c,0x97,0x55,0xa8,0x74,0x1e,0x75,0x83,0x13,
  0xd1,0x70,0x5,0xf7,0x3f,0x44,0x5e,0x8a,0x80,0xe0,0xc2,0xb9,0x2d,0x44,0xd7,0xdc,
  0xb7,0x86,0x6c,0x6b,0x4a,0xf4,0x3,0x83,0x77,0x29,0x96,0xae,0xe0,0xa3,0xcd,0x8b,
  0x25,0xa7,0x8e,0x1a,0x6f,0xe2,0x14,0xb5,0x33,0x3d,0xb0,0xac,0xb1,0x1d,0x13,0xe,
  0xc6,0x5f,0x4b,0xe4,0x40,0xda,0xe6,0xf4,0xf0,0xbf,0xc0,0xcd,0x54,0x86,0x26,0xd5,
  0x7c,0xda,0xc8,0xb9,0x79,0x5b,0x39,0xb9,0xe3,0x8e,0xd3,0xc1,0x74,0x87,0xee,0x87,
  0xfd,0xa3,0xcd,0x46,0xb4,0xad,0xa2,0x3d,0x37,0xf1,0xdf,0xc3,0x78,0x92,0x5c,0xbe,
  0x1f,0x87,0xf6,0xce,0x36,0x61,0x7f,0x79,0xb9,0x2e,0xe1,0xba,0x6d,0xbf,0xb1,0x5f,
  0x9f,0x60,0xd4,0xdf,0xc3,0xe3,0x6f,0x60,0xd4,0xef,0xea,0xd3,0x27,0x9c,0x70,0xdd,
  0xa0,0x9d,0x3b,0x1d,0xd2,0x2e,0x83,0xa6,0xf4,0x24,0x13,0x38,0xb3,0x11,0x59,0x72,
  0xdd,0x8e,0xdd,0x23,0x25,0x1e,0x9f,0x75,0xf,0x94,0xc3,0x66,0xf9,0xb9,0x5e,0x41,
  0xe0,0x9f,0xcd,0x67,0xef,0x87,0xc9,0xa7,0x49,0x4c,0x32,0x48,0x5b,0x90,0xd6,0x24,
  0xc4,0xc1,0x67,0x5a,0x8f,0xc7,0xc9,0x65,0xf2,0x89,0x4c,0xe,0xbd,0xbf,0xb8,0xcc,
  0x54,0x6d,0x60,0x18,0xf7,0xe0,0x74,0x15,0xba,0xa5,0x10,0x79,0x38,0x2e,0xc8,0xd3,
  0xa4,0xbe,0x8b,0x7d,0x71,0x90,0x6b,0x48,0x86,0xd2,0xdb,0xaf,0xa7,0x83,0x19,0x2b,
  0xb8,0x58,0x9e,0x9e,0xe1,0x3f,0xec,0x63,0x5,0x57,0x4c,0x9a,0x41,0xd4,0xae,0xd,
  0x32,0x6e,0x4a,0xc1,0x1e,0x4,0xe1,0xf3,0xcf,0xb7,0xf8,0xc7,0x97,0x41,0xd4,0xc5,
  0x6,0x51,0x7,0xb5,0x7,0xdd,0xd,0xa,0x7f,0x2a,0xa9,0xfe,0x1b,0xd9,0x65,0xec,
  0xe1,0x9f,0x1b,0x1e,0x35,0x9f,0xed,0x86,0x76,0xd1,0x3d,0xec,0xff,0x85,0x7d,0xc7,
  0xad,0xb1,0x1a,0x59,0x1,0x1f,0xe9,0xe2,0xdd,0x31,0x34,0x5b,0x92,0xf6,0x24,0xdf,
  0x95,0x64,0xc7,0x58,0xed,0xca,0xdc,0xd3,0xfd,0x28,0x74,0xdb,0xc7,0x75,0x5b,0xd6,
  0x8f,0x40,0x13,0x3d,0xfc,0x67,0xf1,0x2f,0x41,0x8d,0x9e,0xd6,
  
};

static const unsigned char qt_resource_name[] = {
  // trolltech
  0x0,0x9,
  0x6,0x33,0x5c,0xb8,
  0x0,0x74,
  0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x6c,0x0,0x74,0x0,0x65,0x0,0x63,0x0,0x68,
    // propertyeditor
  0x0,0xe,
  0xd,0x76,0x85,0xe2,
  0x0,0x70,
  0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x79,0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // fontmapping.xml
  0x0,0xf,
  0x7,0x30,0xe4,0x7c,
  0x0,0x66,
  0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x6d,0x0,0x61,0x0,0x70,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/trolltech
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/trolltech/propertyeditor
  0x0,0x0,0x0,0x18,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
  // :/trolltech/propertyeditor/fontmapping.xml
  0x0,0x0,0x0,0x3a,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_propertyeditor)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_propertyeditor))

int QT_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_propertyeditor))

==> qt4-debuginfo-4.8.7-4.tar.xz: usr/src/debug/qt4-4.8.7-4/tools/designer/src/components/lib/.rcc/release-shared/qrc_propertyeditor.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt4/qt4-4.8.7-4.i686/src/qt-everywhere-opensource-src-4.8.7/tools/designer/src/components/propertyeditor/fontmapping.xml
  0x0,0x0,0x3,0x8d,
  0x0,
  0x0,0x10,0x80,0x78,0x9c,0xed,0x56,0x61,0x6f,0xdb,0x36,0x10,0xfd,0x9e,0x5f,0x71,
  0x33,0x82,0x61,0x1b,0x22,0x29,0xee,0x50,0xa0,0xc8,0xdc,0x14,0xad,0xa3,0x4,0x1,
  0x3c,0xd7,0x45,0x94,0x6e,0x45,0x51,0x4,0xb4,0x74,0x96,0xb9,0x52,0xa4,0x42,0x52,
  0x56,0xfc,0xef,0x77,0xa4,0xa4,0xd8,0x71,0xec,0x21,0x3,0xd2,0xa2,0x1f,0x6c,0x18,
  0xb0,0xcd,0x3b,0xbe,0x77,0x7c,0xf7,0x8e,0xf2,0xe0,0xcd,0x5d,0x21,0x60,0x81,0xda,
  0x70,0x25,0x5f,0xf7,0xfa,0xe1,0x71,0xf,0x50,0xa6,0x2a,0xe3,0x32,0x7f,0xdd,0xbb,
  0x4e,0xce,0x83,0x57,0xbd,0x37,0xa7,0x7,0x7,0x83,0x9f,0x82,0xe0,0xb7,0x67,0x7a,
  0x1d,0xf8,0x37,0xc,0x55,0xb9,0xd4,0x3c,0x9f,0x5b,0xf8,0x65,0xf8,0x2b,0xbc,0x38,
  0xee,0xbf,0x84,0x64,0x8e,0xf0,0xc1,0x52,0xa4,0x28,0x99,0x5c,0xc2,0xc8,0x66,0x61,
  0x93,0x29,0x2d,0x4b,0xed,0x9,0xcc,0xad,0x2d,0x4f,0xa2,0xa8,0xae,0xeb,0xf0,0xd6,
  0x86,0x5c,0x45,0x82,0xa7,0x28,0xd,0xd5,0x1a,0xb5,0xa0,0xc9,0x9c,0x1b,0x98,0x71,
  0x81,0x40,0x9f,0x25,0xd3,0x16,0xd4,0xc,0x6c,0x3,0x7b,0x86,0x86,0xe7,0x12,0xf5,
  0xda,0x52,0xa2,0x94,0xf8,0xca,0x6d,0xd8,0xee,0x3e,0xfc,0x90,0xdc,0xbc,0x8b,0x2f,
  0x2e,0xc7,0x37,0xa3,0xcb,0x61,0x3c,0xbe,0x8a,0x4f,0x46,0x17,0x93,0xd1,0x61,0x53,
  0x43,0x51,0xa0,0x4e,0x39,0x13,0x30,0xf2,0xa4,0x8,0xd7,0x86,0xe5,0xe8,0x62,0xed,
  0x2,0x1a,0x98,0x2b,0xe1,0x94,0x83,0x5,0x13,0x3c,0x83,0x74,0xb5,0x87,0xb8,0x9a,
  0x5a,0x29,0xa9,0x60,0x4b,0xa8,0x68,0xbf,0x5d,0xd5,0x2a,0x1d,0xc,0x4b,0x53,0xa5,
  0x33,0x26,0x53,0x84,0x9a,0xdb,0xb9,0xaf,0x71,0xd,0xa2,0xdd,0xf,0x2c,0xd7,0x88,
  0x5,0x4a,0xb,0xa5,0x56,0xb,0x9e,0x61,0x76,0x9f,0xee,0x50,0xae,0xd4,0xcc,0xd6,
  0x4c,0x23,0x28,0x7d,0x4,0x4c,0x58,0xd4,0x92,0x59,0xbe,0x40,0xb1,0x3c,0x22,0x9e,
  0xad,0x24,0x94,0x53,0x18,0xa2,0x22,0x95,0xb9,0x24,0xb8,0xb6,0x1c,0xa8,0x35,0xb7,
  0x16,0xe5,0x1a,0xe3,0x14,0x6d,0x8d,0xb4,0xb2,0x54,0x15,0x30,0x99,0x6d,0x34,0x2c,
  0x84,0x73,0xa5,0xe1,0xbe,0x27,0xd,0xae,0x87,0x92,0x4e,0xc,0x99,0x71,0x4b,0x2e,
  0x33,0x40,0x52,0x3d,0x6e,0xa5,0x4f,0xe,0x56,0x59,0xd,0xd8,0xac,0xd2,0x54,0xa1,
  0x76,0x20,0x5c,0xce,0x94,0x2e,0x98,0xb,0xb6,0xf2,0x61,0x53,0x73,0x6a,0xc1,0x45,
  0x80,0xd9,0xc7,0xa8,0x6d,0x42,0x50,0x99,0xae,0xc7,0x17,0xe3,0x6b,0x18,0xa1,0x31,
  0xe4,0x83,0xb,0x24,0x37,0x90,0xb2,0x93,0x6a,0x4a,0x45,0x3f,0xee,0xeb,0xdb,0x87,
  0xea,0xad,0xfa,0xe5,0x3a,0x38,0x45,0x57,0x45,0x6,0x95,0xcc,0x8,0x6a,0x25,0x63,
  0x6b,0xae,0x15,0x8d,0x27,0xdd,0xce,0xd4,0xce,0x1d,0xbc,0x8,0xfb,0xc0,0xc8,0xaf,
  0x2e,0x6a,0xe6,0x4,0x3a,0x5d,0x7a,0x90,0x73,0xd2,0xfd,0xbe,0xa1,0xe,0xe7,0x5c,
  0x11,0x5d,0x23,0x81,0xd3,0x94,0x95,0x25,0x32,0xed,0xa4,0xa6,0xce,0xba,0xd,0xbe,
  0xba,0xd6,0xbb,0xa1,0xf3,0x2e,0x5,0x52,0x51,0x65,0xbe,0xa9,0x9d,0x43,0x4a,0x96,
  0x7e,0x65,0xb9,0xdb,0xe5,0x6b,0x6d,0xf,0x15,0x2,0x4c,0x4,0x32,0xaa,0x4a,0xe3,
  0x82,0x63,0xdd,0xe0,0x29,0x21,0x54,0xdd,0x10,0xac,0xd4,0xb7,0xca,0xc1,0xd0,0x9,
  0x2a,0x8d,0x1b,0x87,0x7d,0xca,0x49,0x35,0xde,0x56,0x5c,0x7b,0x43,0x79,0x77,0xd4,
  0x5c,0x8,0x27,0x67,0x81,0xf,0x47,0x3c,0x97,0x55,0xa8,0x74,0x1e,0x75,0x83,0x13,
  0xd1,0x70,0x5,0xf7,0x3f,0x44,0x5e,0x8a,0x80,0xe0,0xc2,0xb9,0x2d,0x44,0xd7,0xdc,
  0xb7,0x86,0x6c,0x6b,0x4a,0xf4,0x3,0x83,0x77,0x29,0x96,0xae,0xe0,0xa3,0xcd,0x8b,
  0x25,0xa7,0x8e,0x1a,0x6f,0xe2,0x14,0xb5,0x33,0x3d,0xb0,0xac,0xb1,0x1d,0x13,0xe,
  0xc6,0x5f,0x4b,0xe4,0x40,0xda,0xe6,0xf4,0xf0,0xbf,0xc0,0xcd,0x54,0x86,0x26,0xd5,
  0x7c,0xda,0xc8,0xb9,0x79,0x5b,0x39,0xb9,0xe3,0x8e,0xd3,0xc1,0x74,0x87,0xee,0x87,
  0xfd,0xa3,0xcd,0x46,0xb4,0xad,0xa2,0x3d,0x37,0xf1,0xdf,0xc3,0x78,0x92,0x5c,0xbe,
  0x1f,0x87,0xf6,0xce,0x36,0x61,0x7f,0x79,0xb9,0x2e,0xe1,0xba,0x6d,0xbf,0xb1,0x5f,
  0x9f,0x60,0xd4,0xdf,0xc3,0xe3,0x6f,0x60,0xd4,0xef,0xea,0xd3,0x27,0x9c,0x70,0xdd,
  0xa0,0x9d,0x3b,0x1d,0xd2,0x2e,0x83,0xa6,0xf4,0x24,0x13,0x38,0xb3,0x11,0x59,0x72,
  0xdd,0x8e,0xdd,0x23,0x25,0x1e,0x9f,0x75,0xf,0x94,0xc3,0x66,0xf9,0xb9,0x5e,0x41,
  0xe0,0x9f,0xcd,0x67,0xef,0x87,0xc9,0xa7,0x49,0x4c,0x32,0x48,0x5b,0x90,0xd6,0x24,
  0xc4,0xc1,0x67,0x5a,0x8f,0xc7,0xc9,0x65,0xf2,0x89,0x4c,0xe,0xbd,0xbf,0xb8,0xcc,
  0x54,0x6d,0x60,0x18,0xf7,0xe0,0x74,0x15,0xba,0xa5,0x10,0x79,0x38,0x2e,0xc8,0xd3,
  0xa4,0xbe,0x8b,0x7d,0x71,0x90,0x6b,0x48,0x86,0xd2,0xdb,0xaf,0xa7,0x83,0x19,0x2b,
  0xb8,0x58,0x9e,0x9e,0xe1,0x3f,0xec,0x63,0x5,0x57,0x4c,0x9a,0x41,0xd4,0xae,0xd,
  0x32,0x6e,0x4a,0xc1,0x1e,0x4,0xe1,0xf3,0xcf,0xb7,0xf8,0xc7,0x97,0x41,0xd4,0xc5,
  0x6,0x51,0x7,0xb5,0x7,0xdd,0xd,0xa,0x7f,0x2a,0xa9,0xfe,0x1b,0xd9,0x65,0xec,
  0xe1,0x9f,0x1b,0x1e,0x35,0x9f,0xed,0x86,0x76,0xd1,0x3d,0xec,0xff,0x85,0x7d,0xc7,
  0xad,0xb1,0x1a,0x59,0x1,0x1f,0xe9,0xe2,0xdd,0x31,0x34,0x5b,0x92,0xf6,0x24,0xdf,
  0x95,0x64,0xc7,0x58,0xed,0xca,0xdc,0xd3,0xfd,0x28,0x74,0xdb,0xc7,0x75,0x5b,0xd6,
  0x8f,0x40,0x13,0x3d,0xfc,0x67,0xf1,0x2f,0x41,0x8d,0x9e,0xd6,
  
};

static const unsigned char qt_resource_name[] = {
  // trolltech
  0x0,0x9,
  0x6,0x33,0x5c,0xb8,
  0x0,0x74,
  0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x6c,0x0,0x74,0x0,0x65,0x0,0x63,0x0,0x68,
    // propertyeditor
  0x0,0xe,
  0xd,0x76,0x85,0xe2,
  0x0,0x70,
  0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x79,0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // fontmapping.xml
  0x0,0xf,
  0x7,0x30,0xe4,0x7c,
  0x0,0x66,
  0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x6d,0x0,0x61,0x0,0x70,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/trolltech
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/trolltech/propertyeditor
  0x0,0x0,0x0,0x18,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
  // :/trolltech/propertyeditor/fontmapping.xml
  0x0,0x0,0x0,0x3a,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_propertyeditor)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_propertyeditor))

int QT_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_propertyeditor))
